"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeNetworkXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNetworkXTimeouts = ComputeNetworkXTimeouts

@typing_extensions.final
class ComputeNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_CREATE_SUBNETWORKS_FIELD_NUMBER: builtins.int
    DELETE_DEFAULT_ROUTES_ON_CREATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_ULA_INTERNAL_IPV6_FIELD_NUMBER: builtins.int
    GATEWAY_IPV4_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INTERNAL_IPV6_RANGE_FIELD_NUMBER: builtins.int
    MTU_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROUTING_MODE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    auto_create_subnetworks: builtins.bool
    delete_default_routes_on_create: builtins.bool
    description: builtins.str
    enable_ula_internal_ipv6: builtins.bool
    gateway_ipv4: builtins.str
    id: builtins.str
    internal_ipv6_range: builtins.str
    mtu: builtins.float
    name: builtins.str
    project: builtins.str
    routing_mode: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        auto_create_subnetworks: builtins.bool = ...,
        delete_default_routes_on_create: builtins.bool = ...,
        description: builtins.str = ...,
        enable_ula_internal_ipv6: builtins.bool = ...,
        gateway_ipv4: builtins.str = ...,
        id: builtins.str = ...,
        internal_ipv6_range: builtins.str = ...,
        mtu: builtins.float = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        routing_mode: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeNetworkXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_create_subnetworks", b"auto_create_subnetworks", "delete_default_routes_on_create", b"delete_default_routes_on_create", "description", b"description", "enable_ula_internal_ipv6", b"enable_ula_internal_ipv6", "gateway_ipv4", b"gateway_ipv4", "id", b"id", "internal_ipv6_range", b"internal_ipv6_range", "mtu", b"mtu", "name", b"name", "project", b"project", "resource_info", b"resource_info", "routing_mode", b"routing_mode", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNetwork = ComputeNetwork

@typing_extensions.final
class ComputeNetworkEndpointXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeNetworkEndpointXTimeouts = ComputeNetworkEndpointXTimeouts

@typing_extensions.final
class ComputeNetworkEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    instance: builtins.str
    ip_address: builtins.str
    network_endpoint_group: builtins.str
    port: builtins.float
    project: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkEndpointXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        ip_address: builtins.str = ...,
        network_endpoint_group: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeNetworkEndpointXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "instance", b"instance", "ip_address", b"ip_address", "network_endpoint_group", b"network_endpoint_group", "port", b"port", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeNetworkEndpoint = ComputeNetworkEndpoint

@typing_extensions.final
class ComputeNetworkEndpointGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeNetworkEndpointGroupXTimeouts = ComputeNetworkEndpointGroupXTimeouts

@typing_extensions.final
class ComputeNetworkEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_PORT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_port: builtins.float
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    network_endpoint_type: builtins.str
    project: builtins.str
    self_link: builtins.str
    size: builtins.float
    subnetwork: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkEndpointGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_port: builtins.float = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_endpoint_type: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        size: builtins.float = ...,
        subnetwork: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeNetworkEndpointGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_port", b"default_port", "description", b"description", "id", b"id", "name", b"name", "network", b"network", "network_endpoint_type", b"network_endpoint_type", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "size", b"size", "subnetwork", b"subnetwork", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeNetworkEndpointGroup = ComputeNetworkEndpointGroup

@typing_extensions.final
class ComputeNetworkPeeringXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNetworkPeeringXTimeouts = ComputeNetworkPeeringXTimeouts

@typing_extensions.final
class ComputeNetworkPeering(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    EXPORT_SUBNET_ROUTES_WITH_PUBLIC_IP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    IMPORT_SUBNET_ROUTES_WITH_PUBLIC_IP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PEER_NETWORK_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STATE_DETAILS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    export_custom_routes: builtins.bool
    export_subnet_routes_with_public_ip: builtins.bool
    id: builtins.str
    import_custom_routes: builtins.bool
    import_subnet_routes_with_public_ip: builtins.bool
    name: builtins.str
    network: builtins.str
    peer_network: builtins.str
    state: builtins.str
    state_details: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkPeeringXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        export_custom_routes: builtins.bool = ...,
        export_subnet_routes_with_public_ip: builtins.bool = ...,
        id: builtins.str = ...,
        import_custom_routes: builtins.bool = ...,
        import_subnet_routes_with_public_ip: builtins.bool = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        peer_network: builtins.str = ...,
        state: builtins.str = ...,
        state_details: builtins.str = ...,
        timeouts: global___ComputeNetworkPeeringXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_custom_routes", b"export_custom_routes", "export_subnet_routes_with_public_ip", b"export_subnet_routes_with_public_ip", "id", b"id", "import_custom_routes", b"import_custom_routes", "import_subnet_routes_with_public_ip", b"import_subnet_routes_with_public_ip", "name", b"name", "network", b"network", "peer_network", b"peer_network", "resource_info", b"resource_info", "state", b"state", "state_details", b"state_details", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNetworkPeering = ComputeNetworkPeering

@typing_extensions.final
class ComputeNetworkPeeringRoutesConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNetworkPeeringRoutesConfigXTimeouts = ComputeNetworkPeeringRoutesConfigXTimeouts

@typing_extensions.final
class ComputeNetworkPeeringRoutesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMPORT_CUSTOM_ROUTES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PEERING_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    export_custom_routes: builtins.bool
    id: builtins.str
    import_custom_routes: builtins.bool
    network: builtins.str
    peering: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeNetworkPeeringRoutesConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        export_custom_routes: builtins.bool = ...,
        id: builtins.str = ...,
        import_custom_routes: builtins.bool = ...,
        network: builtins.str = ...,
        peering: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeNetworkPeeringRoutesConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_custom_routes", b"export_custom_routes", "id", b"id", "import_custom_routes", b"import_custom_routes", "network", b"network", "peering", b"peering", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNetworkPeeringRoutesConfig = ComputeNetworkPeeringRoutesConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_dataflow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_dataflow.proto\x12\x18oak9.tython.gcp.dataflow\x1a\x13shared/shared.proto\"&\n\x14\x44\x61taflowJobXTimeouts\x12\x0e\n\x06update\x18\x01 \x01(\t\"\xdb\x07\n\x0b\x44\x61taflowJob\x12\x1e\n\x16\x61\x64\x64itional_experiments\x18\x01 \x03(\t\x12\x1f\n\x17\x65nable_streaming_engine\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x18\n\x10ip_configuration\x18\x04 \x01(\t\x12\x0e\n\x06job_id\x18\x05 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x06 \x01(\t\x12\x41\n\x06labels\x18\x07 \x03(\x0b\x32\x31.oak9.tython.gcp.dataflow.DataflowJob.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x08 \x01(\t\x12\x13\n\x0bmax_workers\x18\t \x01(\x01\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07network\x18\x0b \x01(\t\x12\x11\n\ton_delete\x18\x0c \x01(\t\x12I\n\nparameters\x18\r \x03(\x0b\x32\x35.oak9.tython.gcp.dataflow.DataflowJob.ParametersEntry\x12\x0f\n\x07project\x18\x0e \x01(\t\x12\x0e\n\x06region\x18\x0f \x01(\t\x12\x1d\n\x15service_account_email\x18\x10 \x01(\t\x12$\n\x1cskip_wait_on_job_termination\x18\x11 \x01(\x08\x12\r\n\x05state\x18\x12 \x01(\t\x12\x12\n\nsubnetwork\x18\x13 \x01(\t\x12\x19\n\x11temp_gcs_location\x18\x14 \x01(\t\x12\x19\n\x11template_gcs_path\x18\x15 \x01(\t\x12_\n\x16transform_name_mapping\x18\x16 \x03(\x0b\x32?.oak9.tython.gcp.dataflow.DataflowJob.TransformNameMappingEntry\x12\x0c\n\x04type\x18\x17 \x01(\t\x12\x0c\n\x04zone\x18\x18 \x01(\t\x12@\n\x08timeouts\x18\x19 \x01(\x0b\x32..oak9.tython.gcp.dataflow.DataflowJobXTimeouts\x12\x37\n\rresource_info\x18\x1a \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19TransformNameMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_dataflow_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATAFLOWJOB_LABELSENTRY._options = None
  _DATAFLOWJOB_LABELSENTRY._serialized_options = b'8\001'
  _DATAFLOWJOB_PARAMETERSENTRY._options = None
  _DATAFLOWJOB_PARAMETERSENTRY._serialized_options = b'8\001'
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._options = None
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._serialized_options = b'8\001'
  _DATAFLOWJOBXTIMEOUTS._serialized_start=73
  _DATAFLOWJOBXTIMEOUTS._serialized_end=111
  _DATAFLOWJOB._serialized_start=114
  _DATAFLOWJOB._serialized_end=1101
  _DATAFLOWJOB_LABELSENTRY._serialized_start=944
  _DATAFLOWJOB_LABELSENTRY._serialized_end=989
  _DATAFLOWJOB_PARAMETERSENTRY._serialized_start=991
  _DATAFLOWJOB_PARAMETERSENTRY._serialized_end=1040
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._serialized_start=1042
  _DATAFLOWJOB_TRANSFORMNAMEMAPPINGENTRY._serialized_end=1101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_composer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_composer.proto\x12\x18oak9.tython.gcp.composer\x1a\x13shared/shared.proto\"A\n)ComposerEnvironmentXConfigXDatabaseConfig\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\"C\n+ComposerEnvironmentXConfigXEncryptionConfig\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"h\n,ComposerEnvironmentXConfigXMaintenanceWindow\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x12\n\nrecurrence\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"p\nDComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks\x12\x12\n\ncidr_block\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"\xc1\x01\n9ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12s\n\x0b\x63idr_blocks\x18\x02 \x03(\x0b\x32^.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks\"\x93\x03\n%ComposerEnvironmentXConfigXNodeConfig\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x1c\n\x14\x65nable_ip_masq_agent\x18\x02 \x01(\x08\x12u\n\x14ip_allocation_policy\x18\x03 \x03(\x0b\x32W.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXNodeConfig.IpAllocationPolicyEntry\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x14\n\x0coauth_scopes\x18\x06 \x03(\t\x12\x17\n\x0fservice_account\x18\x07 \x01(\t\x12\x12\n\nsubnetwork\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x0c\n\x04zone\x18\n \x01(\t\x1a\x39\n\x17IpAllocationPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x02\n3ComposerEnvironmentXConfigXPrivateEnvironmentConfig\x12,\n$cloud_composer_connection_subnetwork\x18\x01 \x01(\t\x12.\n&cloud_composer_network_ipv4_cidr_block\x18\x02 \x01(\t\x12!\n\x19\x63loud_sql_ipv4_cidr_block\x18\x03 \x01(\t\x12\x1f\n\x17\x65nable_private_endpoint\x18\x04 \x01(\x08\x12(\n enable_privately_used_public_ips\x18\x05 \x01(\x08\x12\x1e\n\x16master_ipv4_cidr_block\x18\x06 \x01(\t\x12\"\n\x1aweb_server_ipv4_cidr_block\x18\x07 \x01(\t\"\xfc\x04\n)ComposerEnvironmentXConfigXSoftwareConfig\x12\x81\x01\n\x18\x61irflow_config_overrides\x18\x01 \x03(\x0b\x32_.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig.AirflowConfigOverridesEntry\x12l\n\renv_variables\x18\x02 \x03(\x0b\x32U.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig.EnvVariablesEntry\x12\x15\n\rimage_version\x18\x03 \x01(\t\x12l\n\rpypi_packages\x18\x04 \x03(\x0b\x32U.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig.PypiPackagesEntry\x12\x16\n\x0epython_version\x18\x05 \x01(\t\x12\x17\n\x0fscheduler_count\x18\x06 \x01(\x01\x1a=\n\x1b\x41irflowConfigOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11PypiPackagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n*ComposerEnvironmentXConfigXWebServerConfig\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\"m\nGComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xb7\x01\n8ComposerEnvironmentXConfigXWebServerNetworkAccessControl\x12{\n\x10\x61llowed_ip_range\x18\x01 \x03(\x0b\x32\x61.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange\"y\n4ComposerEnvironmentXConfigXWorkloadsConfigXScheduler\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0b\n\x03\x63pu\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12\x12\n\nstorage_gb\x18\x04 \x01(\x01\"j\n4ComposerEnvironmentXConfigXWorkloadsConfigXWebServer\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x11\n\tmemory_gb\x18\x02 \x01(\x01\x12\x12\n\nstorage_gb\x18\x03 \x01(\x01\"\x8d\x01\n1ComposerEnvironmentXConfigXWorkloadsConfigXWorker\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x11\n\tmax_count\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12\x11\n\tmin_count\x18\x04 \x01(\x01\x12\x12\n\nstorage_gb\x18\x05 \x01(\x01\"\xd0\x02\n*ComposerEnvironmentXConfigXWorkloadsConfig\x12\x61\n\tscheduler\x18\x01 \x01(\x0b\x32N.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfigXScheduler\x12\x62\n\nweb_server\x18\x02 \x01(\x0b\x32N.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfigXWebServer\x12[\n\x06worker\x18\x03 \x01(\x0b\x32K.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfigXWorker\"\x97\t\n\x1a\x43omposerEnvironmentXConfig\x12\x13\n\x0b\x61irflow_uri\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61g_gcs_prefix\x18\x02 \x01(\t\x12\x18\n\x10\x65nvironment_size\x18\x03 \x01(\t\x12\x13\n\x0bgke_cluster\x18\x04 \x01(\t\x12\x12\n\nnode_count\x18\x05 \x01(\x01\x12\\\n\x0f\x64\x61tabase_config\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXDatabaseConfig\x12`\n\x11\x65ncryption_config\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXEncryptionConfig\x12\x62\n\x12maintenance_window\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXMaintenanceWindow\x12~\n!master_authorized_networks_config\x18\t \x01(\x0b\x32S.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig\x12T\n\x0bnode_config\x18\n \x01(\x0b\x32?.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXNodeConfig\x12q\n\x1aprivate_environment_config\x18\x0b \x01(\x0b\x32M.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXPrivateEnvironmentConfig\x12\\\n\x0fsoftware_config\x18\x0c \x01(\x0b\x32\x43.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXSoftwareConfig\x12_\n\x11web_server_config\x18\r \x01(\x0b\x32\x44.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWebServerConfig\x12}\n!web_server_network_access_control\x18\x0e \x01(\x0b\x32R.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWebServerNetworkAccessControl\x12^\n\x10workloads_config\x18\x0f \x01(\x0b\x32\x44.oak9.tython.gcp.composer.ComposerEnvironmentXConfigXWorkloadsConfig\"N\n\x1c\x43omposerEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x93\x03\n\x13\x43omposerEnvironment\x12\n\n\x02id\x18\x01 \x01(\t\x12I\n\x06labels\x18\x02 \x03(\x0b\x32\x39.oak9.tython.gcp.composer.ComposerEnvironment.LabelsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x44\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x34.oak9.tython.gcp.composer.ComposerEnvironmentXConfig\x12H\n\x08timeouts\x18\x07 \x01(\x0b\x32\x36.oak9.tython.gcp.composer.ComposerEnvironmentXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_composer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._options = None
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENT_LABELSENTRY._options = None
  _COMPOSERENVIRONMENT_LABELSENTRY._serialized_options = b'8\001'
  _COMPOSERENVIRONMENTXCONFIGXDATABASECONFIG._serialized_start=73
  _COMPOSERENVIRONMENTXCONFIGXDATABASECONFIG._serialized_end=138
  _COMPOSERENVIRONMENTXCONFIGXENCRYPTIONCONFIG._serialized_start=140
  _COMPOSERENVIRONMENTXCONFIGXENCRYPTIONCONFIG._serialized_end=207
  _COMPOSERENVIRONMENTXCONFIGXMAINTENANCEWINDOW._serialized_start=209
  _COMPOSERENVIRONMENTXCONFIGXMAINTENANCEWINDOW._serialized_end=313
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIGXCIDRBLOCKS._serialized_start=315
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIGXCIDRBLOCKS._serialized_end=427
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIG._serialized_start=430
  _COMPOSERENVIRONMENTXCONFIGXMASTERAUTHORIZEDNETWORKSCONFIG._serialized_end=623
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG._serialized_start=626
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG._serialized_end=1029
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._serialized_start=972
  _COMPOSERENVIRONMENTXCONFIGXNODECONFIG_IPALLOCATIONPOLICYENTRY._serialized_end=1029
  _COMPOSERENVIRONMENTXCONFIGXPRIVATEENVIRONMENTCONFIG._serialized_start=1032
  _COMPOSERENVIRONMENTXCONFIGXPRIVATEENVIRONMENTCONFIG._serialized_end=1357
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG._serialized_start=1360
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG._serialized_end=1996
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._serialized_start=1829
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_AIRFLOWCONFIGOVERRIDESENTRY._serialized_end=1890
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._serialized_start=1892
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_ENVVARIABLESENTRY._serialized_end=1943
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._serialized_start=1945
  _COMPOSERENVIRONMENTXCONFIGXSOFTWARECONFIG_PYPIPACKAGESENTRY._serialized_end=1996
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERCONFIG._serialized_start=1998
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERCONFIG._serialized_end=2064
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROLXALLOWEDIPRANGE._serialized_start=2066
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROLXALLOWEDIPRANGE._serialized_end=2175
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROL._serialized_start=2178
  _COMPOSERENVIRONMENTXCONFIGXWEBSERVERNETWORKACCESSCONTROL._serialized_end=2361
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXSCHEDULER._serialized_start=2363
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXSCHEDULER._serialized_end=2484
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWEBSERVER._serialized_start=2486
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWEBSERVER._serialized_end=2592
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWORKER._serialized_start=2595
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIGXWORKER._serialized_end=2736
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIG._serialized_start=2739
  _COMPOSERENVIRONMENTXCONFIGXWORKLOADSCONFIG._serialized_end=3075
  _COMPOSERENVIRONMENTXCONFIG._serialized_start=3078
  _COMPOSERENVIRONMENTXCONFIG._serialized_end=4253
  _COMPOSERENVIRONMENTXTIMEOUTS._serialized_start=4255
  _COMPOSERENVIRONMENTXTIMEOUTS._serialized_end=4333
  _COMPOSERENVIRONMENT._serialized_start=4336
  _COMPOSERENVIRONMENT._serialized_end=4739
  _COMPOSERENVIRONMENT_LABELSENTRY._serialized_start=4694
  _COMPOSERENVIRONMENT_LABELSENTRY._serialized_end=4739
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_sdb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_sdb.proto\x12\x13oak9.tython.aws.sdb\x1a\x13shared/shared.proto\"V\n\x06\x44omain\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"2\n\x03SDB\x12+\n\x06\x64omain\x18\x01 \x03(\x0b\x32\x1b.oak9.tython.aws.sdb.Domainb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_sdb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAIN._serialized_start=63
  _DOMAIN._serialized_end=149
  _SDB._serialized_start=151
  _SDB._serialized_end=201
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CertificateValidity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___CertificateValidity = CertificateValidity

@typing_extensions.final
class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ARN_FIELD_NUMBER: builtins.int
    CERTIFICATE_SIGNING_REQUEST_FIELD_NUMBER: builtins.int
    SIGNING_ALGORITHM_FIELD_NUMBER: builtins.int
    TEMPLATE_ARN_FIELD_NUMBER: builtins.int
    VALIDITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_authority_arn: builtins.str
    certificate_signing_request: builtins.str
    signing_algorithm: builtins.str
    template_arn: builtins.str
    @property
    def validity(self) -> global___CertificateValidity: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_authority_arn: builtins.str = ...,
        certificate_signing_request: builtins.str = ...,
        signing_algorithm: builtins.str = ...,
        template_arn: builtins.str = ...,
        validity: global___CertificateValidity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "validity", b"validity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority_arn", b"certificate_authority_arn", "certificate_signing_request", b"certificate_signing_request", "resource_info", b"resource_info", "signing_algorithm", b"signing_algorithm", "template_arn", b"template_arn", "validity", b"validity"]) -> None: ...

global___Certificate = Certificate

@typing_extensions.final
class ACMPCA(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ACTIVATION_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    @property
    def certificate_authority(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateAuthority]: ...
    @property
    def certificate_authority_activation(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateAuthorityActivation]: ...
    def __init__(
        self,
        *,
        certificate: collections.abc.Iterable[global___Certificate] | None = ...,
        certificate_authority: collections.abc.Iterable[global___CertificateAuthority] | None = ...,
        certificate_authority_activation: collections.abc.Iterable[global___CertificateAuthorityActivation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_authority", b"certificate_authority", "certificate_authority_activation", b"certificate_authority_activation"]) -> None: ...

global___ACMPCA = ACMPCA

@typing_extensions.final
class CertificateAuthoritySubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNIT_FIELD_NUMBER: builtins.int
    DISTINGUISHED_NAME_QUALIFIER_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    COMMON_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    LOCALITY_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SURNAME_FIELD_NUMBER: builtins.int
    GIVEN_NAME_FIELD_NUMBER: builtins.int
    INITIALS_FIELD_NUMBER: builtins.int
    PSEUDONYM_FIELD_NUMBER: builtins.int
    GENERATION_QUALIFIER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    country: builtins.str
    organization: builtins.str
    organizational_unit: builtins.str
    distinguished_name_qualifier: builtins.str
    state: builtins.str
    common_name: builtins.str
    serial_number: builtins.str
    locality: builtins.str
    title: builtins.str
    surname: builtins.str
    given_name: builtins.str
    initials: builtins.str
    pseudonym: builtins.str
    generation_qualifier: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        country: builtins.str = ...,
        organization: builtins.str = ...,
        organizational_unit: builtins.str = ...,
        distinguished_name_qualifier: builtins.str = ...,
        state: builtins.str = ...,
        common_name: builtins.str = ...,
        serial_number: builtins.str = ...,
        locality: builtins.str = ...,
        title: builtins.str = ...,
        surname: builtins.str = ...,
        given_name: builtins.str = ...,
        initials: builtins.str = ...,
        pseudonym: builtins.str = ...,
        generation_qualifier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_name", b"common_name", "country", b"country", "distinguished_name_qualifier", b"distinguished_name_qualifier", "generation_qualifier", b"generation_qualifier", "given_name", b"given_name", "initials", b"initials", "locality", b"locality", "organization", b"organization", "organizational_unit", b"organizational_unit", "pseudonym", b"pseudonym", "resource_info", b"resource_info", "serial_number", b"serial_number", "state", b"state", "surname", b"surname", "title", b"title"]) -> None: ...

global___CertificateAuthoritySubject = CertificateAuthoritySubject

@typing_extensions.final
class CertificateAuthorityCrlConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    EXPIRATION_IN_DAYS_FIELD_NUMBER: builtins.int
    CUSTOM_CNAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    expiration_in_days: builtins.int
    custom_cname: builtins.str
    s3_bucket_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        expiration_in_days: builtins.int = ...,
        custom_cname: builtins.str = ...,
        s3_bucket_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_cname", b"custom_cname", "enabled", b"enabled", "expiration_in_days", b"expiration_in_days", "resource_info", b"resource_info", "s3_bucket_name", b"s3_bucket_name"]) -> None: ...

global___CertificateAuthorityCrlConfiguration = CertificateAuthorityCrlConfiguration

@typing_extensions.final
class CertificateAuthorityRevocationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CRL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def crl_configuration(self) -> global___CertificateAuthorityCrlConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        crl_configuration: global___CertificateAuthorityCrlConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["crl_configuration", b"crl_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["crl_configuration", b"crl_configuration", "resource_info", b"resource_info"]) -> None: ...

global___CertificateAuthorityRevocationConfiguration = CertificateAuthorityRevocationConfiguration

@typing_extensions.final
class CertificateAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    KEY_ALGORITHM_FIELD_NUMBER: builtins.int
    SIGNING_ALGORITHM_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    REVOCATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    key_algorithm: builtins.str
    signing_algorithm: builtins.str
    @property
    def subject(self) -> global___CertificateAuthoritySubject: ...
    @property
    def revocation_configuration(self) -> global___CertificateAuthorityRevocationConfiguration: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        key_algorithm: builtins.str = ...,
        signing_algorithm: builtins.str = ...,
        subject: global___CertificateAuthoritySubject | None = ...,
        revocation_configuration: global___CertificateAuthorityRevocationConfiguration | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "revocation_configuration", b"revocation_configuration", "subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_algorithm", b"key_algorithm", "resource_info", b"resource_info", "revocation_configuration", b"revocation_configuration", "signing_algorithm", b"signing_algorithm", "subject", b"subject", "tags", b"tags", "type", b"type"]) -> None: ...

global___CertificateAuthority = CertificateAuthority

@typing_extensions.final
class CertificateAuthorityActivation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ARN_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_CHAIN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_authority_arn: builtins.str
    certificate: builtins.str
    certificate_chain: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_authority_arn: builtins.str = ...,
        certificate: builtins.str = ...,
        certificate_chain: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_authority_arn", b"certificate_authority_arn", "certificate_chain", b"certificate_chain", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___CertificateAuthorityActivation = CertificateAuthorityActivation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_certificatemanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n aws/aws_certificatemanager.proto\x12\"oak9.tython.aws.certificatemanager\x1a\x13shared/shared.proto\"\xa4\x01\n!CertificateDomainValidationOption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x03 \x01(\t\x12\x19\n\x11validation_domain\x18\x04 \x01(\t\"\xd1\x03\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x65rtificate_authority_arn\x18\x02 \x01(\t\x12\x33\n+certificate_transparency_logging_preference\x18\x03 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x04 \x01(\t\x12h\n\x19\x64omain_validation_options\x18\x05 \x03(\x0b\x32\x45.oak9.tython.aws.certificatemanager.CertificateDomainValidationOption\x12!\n\x19subject_alternative_names\x18\x06 \x03(\t\x12G\n\x04tags\x18\x07 \x03(\x0b\x32\x39.oak9.tython.aws.certificatemanager.Certificate.TagsEntry\x12\x19\n\x11validation_method\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x12\x43\x65rtificateManager\x12\x44\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32/.oak9.tython.aws.certificatemanager.Certificateb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_certificatemanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATE_TAGSENTRY._options = None
  _CERTIFICATE_TAGSENTRY._serialized_options = b'8\001'
  _CERTIFICATEDOMAINVALIDATIONOPTION._serialized_start=94
  _CERTIFICATEDOMAINVALIDATIONOPTION._serialized_end=258
  _CERTIFICATE._serialized_start=261
  _CERTIFICATE._serialized_end=726
  _CERTIFICATE_TAGSENTRY._serialized_start=683
  _CERTIFICATE_TAGSENTRY._serialized_end=726
  _CERTIFICATEMANAGER._serialized_start=728
  _CERTIFICATEMANAGER._serialized_end=818
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgcp/gcp_compute_image.proto\x12\x1doak9.tython.gcp.compute_image\x1a\x13shared/shared.proto\",\n\x1c\x43omputeImageXGuestOsFeatures\x12\x0c\n\x04type\x18\x01 \x01(\t\"L\n\x14\x43omputeImageXRawDisk\x12\x16\n\x0e\x63ontainer_type\x18\x01 \x01(\t\x12\x0c\n\x04sha1\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"G\n\x15\x43omputeImageXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x05\n\x0c\x43omputeImage\x12\x1a\n\x12\x61rchive_size_bytes\x18\x01 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x01\x12\x0e\n\x06\x66\x61mily\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x07 \x01(\t\x12G\n\x06labels\x18\x08 \x03(\x0b\x32\x37.oak9.tython.gcp.compute_image.ComputeImage.LabelsEntry\x12\x10\n\x08licenses\x18\t \x03(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12\x13\n\x0bsource_disk\x18\r \x01(\t\x12\x14\n\x0csource_image\x18\x0e \x01(\t\x12\x17\n\x0fsource_snapshot\x18\x0f \x01(\t\x12V\n\x11guest_os_features\x18\x10 \x03(\x0b\x32;.oak9.tython.gcp.compute_image.ComputeImageXGuestOsFeatures\x12\x45\n\x08raw_disk\x18\x11 \x01(\x0b\x32\x33.oak9.tython.gcp.compute_image.ComputeImageXRawDisk\x12\x46\n\x08timeouts\x18\x12 \x01(\x0b\x32\x34.oak9.tython.gcp.compute_image.ComputeImageXTimeouts\x12\x37\n\rresource_info\x18\x13 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n ComputeImageIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfe\x01\n\x16\x43omputeImageIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12R\n\tcondition\x18\x07 \x01(\x0b\x32?.oak9.tython.gcp.compute_image.ComputeImageIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1f\x43omputeImageIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfb\x01\n\x15\x43omputeImageIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.compute_image.ComputeImageIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9f\x01\n\x15\x43omputeImageIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEIMAGE_LABELSENTRY._options = None
  _COMPUTEIMAGE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEIMAGEXGUESTOSFEATURES._serialized_start=83
  _COMPUTEIMAGEXGUESTOSFEATURES._serialized_end=127
  _COMPUTEIMAGEXRAWDISK._serialized_start=129
  _COMPUTEIMAGEXRAWDISK._serialized_end=205
  _COMPUTEIMAGEXTIMEOUTS._serialized_start=207
  _COMPUTEIMAGEXTIMEOUTS._serialized_end=278
  _COMPUTEIMAGE._serialized_start=281
  _COMPUTEIMAGE._serialized_end=993
  _COMPUTEIMAGE_LABELSENTRY._serialized_start=948
  _COMPUTEIMAGE_LABELSENTRY._serialized_end=993
  _COMPUTEIMAGEIAMBINDINGXCONDITION._serialized_start=995
  _COMPUTEIMAGEIAMBINDINGXCONDITION._serialized_end=1085
  _COMPUTEIMAGEIAMBINDING._serialized_start=1088
  _COMPUTEIMAGEIAMBINDING._serialized_end=1342
  _COMPUTEIMAGEIAMMEMBERXCONDITION._serialized_start=1344
  _COMPUTEIMAGEIAMMEMBERXCONDITION._serialized_end=1433
  _COMPUTEIMAGEIAMMEMBER._serialized_start=1436
  _COMPUTEIMAGEIAMMEMBER._serialized_end=1687
  _COMPUTEIMAGEIAMPOLICY._serialized_start=1690
  _COMPUTEIMAGEIAMPOLICY._serialized_end=1849
# @@protoc_insertion_point(module_scope)



class SaCExceptions(Exception):
    
    def __init__(self, meta_info: object):
        """_summary_
        SaC exception object will add on the request ID and Caller type to SaC Exceptions. 

        Args:
            resource (object): Resource that is currently being evaluated by SaC
        """

        try:
            self.request_id = meta_info.request_id
            self.validation_type = meta_info.caller

        except Exception as e:
            
            self.request_id = "Request ID Not Available"
            self.validation_type = "Caller Type Not Available"

    def __str__(self):
        return f'{self.error_code}: {self.message}'


class ViolationException(SaCExceptions):

    def __init__(self, exception: Exception):
        """_summary_
        
        SaC exception object meant to handle generic Exceptions and ConfigIdExceptions that occurs during violation object creation.

        Args:
            exception (Exception): e object generated by an Exception
        """

        try:
            # Build violation object based on configID Exception
            self.error_message = exception.error_message
            self.error_code = exception.error_code
            self.request_id = exception.request_id
            self.exception_type = exception.exception_type
            
        except Exception as e:

            self.error_code = "500"
            self.error_message = f"Could not access property {exception} on resource"
            self.exception_type = exception
            super().__init__(exception)


class ConfigIdException(SaCExceptions):

    def __init__(self, resource: object, config_name: str = ""):
        """_summary_
        SaC Exception object for handling errors related to config id generation. This exception will feed into ViolationException when raised.

        Args:
            resource (object): Resource that is currently being evaluated by SaC
            config_name (str): Name of the config that could not be generated
        """
        self.error_code = "505"
        self.error_message = f"Unable to generate config_id for resource with config name: {config_name}"
        self.exception_type = "Unable to generate config id"
        
        super().__init__(resource)


class GrpcPopulationException(SaCExceptions):

    def __init__(self, meta_info: object, exception: Exception):
        """_summary_
        SaC Exception object for handling errors related to GRPC object creation. Currently it covers all GRPC objects that the runner generates.

        Args:
            resource (object): Resource that is currently being evaluated by SaC
            exception (Exception): e object generated by an Exception
        """
        
        self.error_code = "510"
        self.exception_type = exception
        self.error_message = f"Unable to populate GRPC Violation, Design_Gap, or Exception Object due to {exception} on resource {meta_info.resource_type}"

        super().__init__(meta_info)


class UnpackingException(SaCExceptions):

    def __init__(self, type_url: str = ""):
        """_summary_
        SaC Exception object for handling errors related to the unpacking of a resource based on the type url.
        
        Args:
            type_url (string): Type url string that is attached to the resource that is sent for validation
        """
        self.error_code = "515"
        self.error_message = f"Could Not Unpack Resource Due To No Matching Resource Found For Type Url {type_url}"
        self.exception_type = "Error In Unpacking Resource"
        self.request_id = "Not Available. Unable To Access Resource Info"
        self.validation_type = "Not Available. Unable To Access Resource Info"


class MessageException(SaCExceptions):
    
    def __init__(self):
        """_summary_
        SaC Exception object for handling errors related to the initial grpc message the runner receives.
        """
        self.error_code = "520"
        self.error_message = f"Grpc Message From Validation Broker Was Undefined Or None."
        self.exception_type = "Grpc Message Could Not Be Interpreted"
        self.request_id = "Not Available. Unable To Access Resource Info"
        self.validation_type = "Not Available. Unable To Access Resource Info"


class BlueprintException(SaCExceptions):
    
    def __init__(self, meta: object):
        """_summary_
        SaC Exception object that handles errors related  to blueprint retrieval for validation

        Args:
            resource (object): Resource that is currently being evaluated by SaC
        """
        self.error_code = "525"
        self.error_message = f"Blueprint matching service could not find a validation blueprint for resource {meta.resource_type}"
        self.exception_type = "Validation Blueprint Could Not Be Found"

        super().__init__(meta)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_gamelift.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_gamelift.proto\x12\x18oak9.tython.aws.gamelift\x1a\x13shared/shared.proto\"r\n\x14\x41liasRoutingStrategy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08\x66leet_id\x18\x03 \x01(\t\"\xad\x01\n\x05\x41lias\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x10routing_strategy\x18\x04 \x01(\x0b\x32..oak9.tython.aws.gamelift.AliasRoutingStrategy\"\xfd\x03\n\x08GameLift\x12.\n\x05\x61lias\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.gamelift.Alias\x12.\n\x05\x62uild\x18\x02 \x03(\x0b\x32\x1f.oak9.tython.aws.gamelift.Build\x12.\n\x05\x66leet\x18\x03 \x03(\x0b\x32\x1f.oak9.tython.aws.gamelift.Fleet\x12\x44\n\x11game_server_group\x18\x04 \x03(\x0b\x32).oak9.tython.aws.gamelift.GameServerGroup\x12\x46\n\x12game_session_queue\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.gamelift.GameSessionQueue\x12U\n\x19matchmaking_configuration\x18\x06 \x03(\x0b\x32\x32.oak9.tython.aws.gamelift.MatchmakingConfiguration\x12J\n\x14matchmaking_rule_set\x18\x07 \x03(\x0b\x32,.oak9.tython.aws.gamelift.MatchmakingRuleSet\x12\x30\n\x06script\x18\x08 \x03(\x0b\x32 .oak9.tython.aws.gamelift.Script\"\x91\x01\n\x0f\x42uildS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x16\n\x0eobject_version\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xbe\x01\n\x05\x42uild\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10operating_system\x18\x03 \x01(\t\x12\x43\n\x10storage_location\x18\x04 \x01(\x0b\x32).oak9.tython.aws.gamelift.BuildS3Location\x12\x0f\n\x07version\x18\x05 \x01(\t\"r\n\x1d\x46leetCertificateConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63\x65rtificate_type\x18\x02 \x01(\t\"\x94\x01\n\x11\x46leetIpPermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfrom_port\x18\x02 \x01(\x05\x12\x10\n\x08ip_range\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x0f\n\x07to_port\x18\x05 \x01(\x05\"\xa4\x01\n FleetResourceCreationLimitPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dnew_game_sessions_per_creator\x18\x02 \x01(\x05\x12 \n\x18policy_period_in_minutes\x18\x03 \x01(\x05\"\x95\x01\n\x12\x46leetServerProcess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63oncurrent_executions\x18\x02 \x01(\x05\x12\x13\n\x0blaunch_path\x18\x03 \x01(\t\x12\x12\n\nparameters\x18\x04 \x01(\t\"\xfe\x01\n\x19\x46leetRuntimeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12/\n\'game_session_activation_timeout_seconds\x18\x02 \x01(\x05\x12/\n\'max_concurrent_game_session_activations\x18\x03 \x01(\x05\x12\x46\n\x10server_processes\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.gamelift.FleetServerProcess\"\xc4\x06\n\x05\x46leet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12Z\n\x19\x63\x65rtificate_configuration\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.gamelift.FleetCertificateConfiguration\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1e\n\x16\x64\x65sired_e_c2_instances\x18\x05 \x01(\x05\x12M\n\x18\x65_c2_inbound_permissions\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.gamelift.FleetIpPermission\x12\x1a\n\x12\x65_c2_instance_type\x18\x07 \x01(\t\x12\x12\n\nfleet_type\x18\x08 \x01(\t\x12\x19\n\x11instance_role_arn\x18\t \x01(\t\x12\x11\n\tlog_paths\x18\n \x03(\t\x12\x10\n\x08max_size\x18\x0b \x01(\x05\x12\x15\n\rmetric_groups\x18\x0c \x03(\t\x12\x10\n\x08min_size\x18\r \x01(\x05\x12\x0c\n\x04name\x18\x0e \x01(\t\x12*\n\"new_game_session_protection_policy\x18\x0f \x01(\t\x12\x1f\n\x17peer_vpc_aws_account_id\x18\x10 \x01(\t\x12\x13\n\x0bpeer_vpc_id\x18\x11 \x01(\t\x12\x62\n\x1eresource_creation_limit_policy\x18\x12 \x01(\x0b\x32:.oak9.tython.aws.gamelift.FleetResourceCreationLimitPolicy\x12R\n\x15runtime_configuration\x18\x13 \x01(\x0b\x32\x33.oak9.tython.aws.gamelift.FleetRuntimeConfiguration\x12\x11\n\tscript_id\x18\x14 \x01(\t\x12 \n\x18server_launch_parameters\x18\x15 \x01(\t\x12\x1a\n\x12server_launch_path\x18\x16 \x01(\t\"{\n*GameServerGroupTargetTrackingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0ctarget_value\x18\x02 \x01(\x01\"\xeb\x01\n GameServerGroupAutoScalingPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x65stimated_instance_warmup\x18\x02 \x01(\x01\x12k\n\x1dtarget_tracking_configuration\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.gamelift.GameServerGroupTargetTrackingConfiguration\"\x8e\x01\n!GameServerGroupInstanceDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x03 \x01(\t\"\xb8\x01\n\"GameServerGroupInstanceDefinitions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x14instance_definitions\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.gamelift.GameServerGroupInstanceDefinition\"\xa3\x01\n\x1dGameServerGroupLaunchTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12launch_template_id\x18\x02 \x01(\t\x12\x1c\n\x14launch_template_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\xc2\x01\n\x13GameServerGroupTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x04tags\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.gamelift.GameServerGroupTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x19GameServerGroupVpcSubnets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bvpc_subnets\x18\x02 \x03(\t\"\x88\x05\n\x0fGameServerGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x13\x61uto_scaling_policy\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.gamelift.GameServerGroupAutoScalingPolicy\x12\x1a\n\x12\x62\x61lancing_strategy\x18\x03 \x01(\t\x12\x15\n\rdelete_option\x18\x04 \x01(\t\x12\x1e\n\x16game_server_group_name\x18\x05 \x01(\t\x12%\n\x1dgame_server_protection_policy\x18\x06 \x01(\t\x12Z\n\x14instance_definitions\x18\x07 \x01(\x0b\x32<.oak9.tython.aws.gamelift.GameServerGroupInstanceDefinitions\x12P\n\x0flaunch_template\x18\x08 \x01(\x0b\x32\x37.oak9.tython.aws.gamelift.GameServerGroupLaunchTemplate\x12\x10\n\x08max_size\x18\t \x01(\x01\x12\x10\n\x08min_size\x18\n \x01(\x01\x12\x10\n\x08role_arn\x18\x0b \x01(\t\x12;\n\x04tags\x18\x0c \x01(\x0b\x32-.oak9.tython.aws.gamelift.GameServerGroupTags\x12H\n\x0bvpc_subnets\x18\r \x01(\x0b\x32\x33.oak9.tython.aws.gamelift.GameServerGroupVpcSubnets\"\xb7\x01\n#GameSessionQueuePlayerLatencyPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17policy_duration_seconds\x18\x02 \x01(\x05\x12\x36\n.maximum_individual_player_latency_milliseconds\x18\x03 \x01(\x05\"o\n\x1bGameSessionQueueDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\"\xa2\x02\n\x10GameSessionQueue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12timeout_in_seconds\x18\x02 \x01(\x05\x12^\n\x17player_latency_policies\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.gamelift.GameSessionQueuePlayerLatencyPolicy\x12K\n\x0c\x64\x65stinations\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.gamelift.GameSessionQueueDestination\x12\x0c\n\x04name\x18\x05 \x01(\t\"{\n$MatchmakingConfigurationGameProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xf4\x03\n\x18MatchmakingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x0fgame_properties\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.gamelift.MatchmakingConfigurationGameProperty\x12\x19\n\x11game_session_data\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\"\n\x1a\x61\x63\x63\x65ptance_timeout_seconds\x18\x05 \x01(\x05\x12\x1b\n\x13notification_target\x18\x06 \x01(\t\x12\x19\n\x11\x63ustom_event_data\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x1f\n\x17\x61\x64\x64itional_player_count\x18\t \x01(\x05\x12\x15\n\rbackfill_mode\x18\n \x01(\t\x12\x1f\n\x17request_timeout_seconds\x18\x0b \x01(\x05\x12\x1b\n\x13\x61\x63\x63\x65ptance_required\x18\x0c \x01(\x08\x12\x15\n\rrule_set_name\x18\r \x01(\t\x12\x1f\n\x17game_session_queue_arns\x18\x0e \x03(\t\"r\n\x12MatchmakingRuleSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rrule_set_body\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x92\x01\n\x10ScriptS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eobject_version\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xa6\x01\n\x06Script\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x44\n\x10storage_location\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.gamelift.ScriptS3Location\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_gamelift_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GAMESERVERGROUPTAGS_TAGSENTRY._options = None
  _GAMESERVERGROUPTAGS_TAGSENTRY._serialized_options = b'8\001'
  _ALIASROUTINGSTRATEGY._serialized_start=73
  _ALIASROUTINGSTRATEGY._serialized_end=187
  _ALIAS._serialized_start=190
  _ALIAS._serialized_end=363
  _GAMELIFT._serialized_start=366
  _GAMELIFT._serialized_end=875
  _BUILDS3LOCATION._serialized_start=878
  _BUILDS3LOCATION._serialized_end=1023
  _BUILD._serialized_start=1026
  _BUILD._serialized_end=1216
  _FLEETCERTIFICATECONFIGURATION._serialized_start=1218
  _FLEETCERTIFICATECONFIGURATION._serialized_end=1332
  _FLEETIPPERMISSION._serialized_start=1335
  _FLEETIPPERMISSION._serialized_end=1483
  _FLEETRESOURCECREATIONLIMITPOLICY._serialized_start=1486
  _FLEETRESOURCECREATIONLIMITPOLICY._serialized_end=1650
  _FLEETSERVERPROCESS._serialized_start=1653
  _FLEETSERVERPROCESS._serialized_end=1802
  _FLEETRUNTIMECONFIGURATION._serialized_start=1805
  _FLEETRUNTIMECONFIGURATION._serialized_end=2059
  _FLEET._serialized_start=2062
  _FLEET._serialized_end=2898
  _GAMESERVERGROUPTARGETTRACKINGCONFIGURATION._serialized_start=2900
  _GAMESERVERGROUPTARGETTRACKINGCONFIGURATION._serialized_end=3023
  _GAMESERVERGROUPAUTOSCALINGPOLICY._serialized_start=3026
  _GAMESERVERGROUPAUTOSCALINGPOLICY._serialized_end=3261
  _GAMESERVERGROUPINSTANCEDEFINITION._serialized_start=3264
  _GAMESERVERGROUPINSTANCEDEFINITION._serialized_end=3406
  _GAMESERVERGROUPINSTANCEDEFINITIONS._serialized_start=3409
  _GAMESERVERGROUPINSTANCEDEFINITIONS._serialized_end=3593
  _GAMESERVERGROUPLAUNCHTEMPLATE._serialized_start=3596
  _GAMESERVERGROUPLAUNCHTEMPLATE._serialized_end=3759
  _GAMESERVERGROUPTAGS._serialized_start=3762
  _GAMESERVERGROUPTAGS._serialized_end=3956
  _GAMESERVERGROUPTAGS_TAGSENTRY._serialized_start=3913
  _GAMESERVERGROUPTAGS_TAGSENTRY._serialized_end=3956
  _GAMESERVERGROUPVPCSUBNETS._serialized_start=3958
  _GAMESERVERGROUPVPCSUBNETS._serialized_end=4063
  _GAMESERVERGROUP._serialized_start=4066
  _GAMESERVERGROUP._serialized_end=4714
  _GAMESESSIONQUEUEPLAYERLATENCYPOLICY._serialized_start=4717
  _GAMESESSIONQUEUEPLAYERLATENCYPOLICY._serialized_end=4900
  _GAMESESSIONQUEUEDESTINATION._serialized_start=4902
  _GAMESESSIONQUEUEDESTINATION._serialized_end=5013
  _GAMESESSIONQUEUE._serialized_start=5016
  _GAMESESSIONQUEUE._serialized_end=5306
  _MATCHMAKINGCONFIGURATIONGAMEPROPERTY._serialized_start=5308
  _MATCHMAKINGCONFIGURATIONGAMEPROPERTY._serialized_end=5431
  _MATCHMAKINGCONFIGURATION._serialized_start=5434
  _MATCHMAKINGCONFIGURATION._serialized_end=5934
  _MATCHMAKINGRULESET._serialized_start=5936
  _MATCHMAKINGRULESET._serialized_end=6050
  _SCRIPTS3LOCATION._serialized_start=6053
  _SCRIPTS3LOCATION._serialized_end=6199
  _SCRIPT._serialized_start=6202
  _SCRIPT._serialized_end=6368
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_macie.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ws/aws_macie.proto\x12\x15oak9.tython.aws.macie\x1a\x13shared/shared.proto\"\xc9\x01\n\x14\x43ustomDataIdentifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05regex\x18\x04 \x01(\t\x12\x1e\n\x16maximum_match_distance\x18\x05 \x01(\x05\x12\x10\n\x08keywords\x18\x06 \x03(\t\x12\x14\n\x0cignore_words\x18\x07 \x03(\t\"\xb5\x02\n\x05Macie\x12K\n\x16\x63ustom_data_identifier\x18\x01 \x03(\x0b\x32+.oak9.tython.aws.macie.CustomDataIdentifier\x12>\n\x0f\x66indings_filter\x18\x02 \x03(\x0b\x32%.oak9.tython.aws.macie.FindingsFilter\x12/\n\x07session\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.aws.macie.Session\x12n\n)findings_filter_findings_filter_list_item\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.macie.FindingsFilterFindingsFilterListItem\"R\n\x17\x46indingsFilterCriterion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n\x1d\x46indingsFilterFindingCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\tcriterion\x18\x02 \x01(\x0b\x32..oak9.tython.aws.macie.FindingsFilterCriterion\"\xde\x01\n\x0e\x46indingsFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12N\n\x10\x66inding_criteria\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.macie.FindingsFilterFindingCriteria\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12\x10\n\x08position\x18\x06 \x01(\x05\"x\n\x07Session\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12$\n\x1c\x66inding_publishing_frequency\x18\x03 \x01(\t\"y\n$FindingsFilterFindingsFilterListItem\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_macie_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CUSTOMDATAIDENTIFIER._serialized_start=68
  _CUSTOMDATAIDENTIFIER._serialized_end=269
  _MACIE._serialized_start=272
  _MACIE._serialized_end=581
  _FINDINGSFILTERCRITERION._serialized_start=583
  _FINDINGSFILTERCRITERION._serialized_end=665
  _FINDINGSFILTERFINDINGCRITERIA._serialized_start=668
  _FINDINGSFILTERFINDINGCRITERIA._serialized_end=823
  _FINDINGSFILTER._serialized_start=826
  _FINDINGSFILTER._serialized_end=1048
  _SESSION._serialized_start=1050
  _SESSION._serialized_end=1170
  _FINDINGSFILTERFINDINGSFILTERLISTITEM._serialized_start=1172
  _FINDINGSFILTERFINDINGSFILTERLISTITEM._serialized_end=1293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.node.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.node.v1.proto\x12\x1boak9.tython.k8s.api.node.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\"\xbc\x01\n\x08Overhead\x12\x46\n\tpod_fixed\x18\x01 \x03(\x0b\x32\x33.oak9.tython.k8s.api.node.v1.Overhead.PodFixedEntry\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rPodFixedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x02\n\x0cRuntimeClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0f\n\x07handler\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\x08overhead\x18\x05 \x01(\x0b\x32%.oak9.tython.k8s.api.node.v1.Overhead\x12;\n\nscheduling\x18\x06 \x01(\x0b\x32\'.oak9.tython.k8s.api.node.v1.Scheduling\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x01\n\x10RuntimeClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x38\n\x05items\x18\x02 \x03(\x0b\x32).oak9.tython.k8s.api.node.v1.RuntimeClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x02\n\nScheduling\x12P\n\rnode_selector\x18\x01 \x03(\x0b\x32\x39.oak9.tython.k8s.api.node.v1.Scheduling.NodeSelectorEntry\x12<\n\x0btolerations\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.core.v1.Toleration\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11NodeSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.node.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OVERHEAD_PODFIXEDENTRY._options = None
  _OVERHEAD_PODFIXEDENTRY._serialized_options = b'8\001'
  _SCHEDULING_NODESELECTORENTRY._options = None
  _SCHEDULING_NODESELECTORENTRY._serialized_options = b'8\001'
  _OVERHEAD._serialized_start=215
  _OVERHEAD._serialized_end=403
  _OVERHEAD_PODFIXEDENTRY._serialized_start=356
  _OVERHEAD_PODFIXEDENTRY._serialized_end=403
  _RUNTIMECLASS._serialized_start=406
  _RUNTIMECLASS._serialized_end=724
  _RUNTIMECLASSLIST._serialized_start=727
  _RUNTIMECLASSLIST._serialized_end=970
  _SCHEDULING._serialized_start=973
  _SCHEDULING._serialized_end=1239
  _SCHEDULING_NODESELECTORENTRY._serialized_start=1188
  _SCHEDULING_NODESELECTORENTRY._serialized_end=1239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_logging.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_logging.proto\x12\x17oak9.tython.gcp.logging\x1a\x13shared/shared.proto\"\xfa\x01\n!LoggingBillingAccountBucketConfig\x12\x17\n\x0f\x62illing_account\x18\x01 \x01(\t\x12\x11\n\tbucket_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0flifecycle_state\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eretention_days\x18\x08 \x01(\x01\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc3\x01\n\x1eLoggingBillingAccountExclusion\x12\x17\n\x0f\x62illing_account\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n)LoggingBillingAccountSinkXBigqueryOptions\x12\x1e\n\x16use_partitioned_tables\x18\x01 \x01(\x08\"k\n$LoggingBillingAccountSinkXExclusions\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x9d\x03\n\x19LoggingBillingAccountSink\x12\x17\n\x0f\x62illing_account\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x03 \x01(\t\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x17\n\x0fwriter_identity\x18\x08 \x01(\t\x12\\\n\x10\x62igquery_options\x18\t \x01(\x0b\x32\x42.oak9.tython.gcp.logging.LoggingBillingAccountSinkXBigqueryOptions\x12Q\n\nexclusions\x18\n \x03(\x0b\x32=.oak9.tython.gcp.logging.LoggingBillingAccountSinkXExclusions\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\x19LoggingFolderBucketConfig\x12\x11\n\tbucket_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66older\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0flifecycle_state\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eretention_days\x18\x08 \x01(\x01\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x01\n\x16LoggingFolderExclusion\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x0e\n\x06\x66older\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n!LoggingFolderSinkXBigqueryOptions\x12\x1e\n\x16use_partitioned_tables\x18\x01 \x01(\x08\"c\n\x1cLoggingFolderSinkXExclusions\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x96\x03\n\x11LoggingFolderSink\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\x0e\n\x06\x66older\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x18\n\x10include_children\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x17\n\x0fwriter_identity\x18\t \x01(\t\x12T\n\x10\x62igquery_options\x18\n \x01(\x0b\x32:.oak9.tython.gcp.logging.LoggingFolderSinkXBigqueryOptions\x12I\n\nexclusions\x18\x0b \x03(\x0b\x32\x35.oak9.tython.gcp.logging.LoggingFolderSinkXExclusions\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\x17LoggingLogViewXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa8\x02\n\x0eLoggingLogView\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0e\n\x06parent\x18\x08 \x01(\t\x12\x13\n\x0bupdate_time\x18\t \x01(\t\x12\x42\n\x08timeouts\x18\n \x01(\x0b\x32\x30.oak9.tython.gcp.logging.LoggingLogViewXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"=\n+LoggingMetricXBucketOptionsXExplicitBuckets\x12\x0e\n\x06\x62ounds\x18\x01 \x03(\x01\"r\n.LoggingMetricXBucketOptionsXExponentialBuckets\x12\x15\n\rgrowth_factor\x18\x01 \x01(\x01\x12\x1a\n\x12num_finite_buckets\x18\x02 \x01(\x01\x12\r\n\x05scale\x18\x03 \x01(\x01\"f\n)LoggingMetricXBucketOptionsXLinearBuckets\x12\x1a\n\x12num_finite_buckets\x18\x01 \x01(\x01\x12\x0e\n\x06offset\x18\x02 \x01(\x01\x12\r\n\x05width\x18\x03 \x01(\x01\"\xbf\x02\n\x1bLoggingMetricXBucketOptions\x12^\n\x10\x65xplicit_buckets\x18\x01 \x01(\x0b\x32\x44.oak9.tython.gcp.logging.LoggingMetricXBucketOptionsXExplicitBuckets\x12\x64\n\x13\x65xponential_buckets\x18\x02 \x01(\x0b\x32G.oak9.tython.gcp.logging.LoggingMetricXBucketOptionsXExponentialBuckets\x12Z\n\x0elinear_buckets\x18\x03 \x01(\x0b\x32\x42.oak9.tython.gcp.logging.LoggingMetricXBucketOptionsXLinearBuckets\"]\n%LoggingMetricXMetricDescriptorXLabels\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x12\n\nvalue_type\x18\x03 \x01(\t\"\xbd\x01\n\x1eLoggingMetricXMetricDescriptor\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x13\n\x0bmetric_kind\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12\x12\n\nvalue_type\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.oak9.tython.gcp.logging.LoggingMetricXMetricDescriptorXLabels\"H\n\x16LoggingMetricXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa5\x04\n\rLoggingMetric\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12U\n\x10label_extractors\x18\x04 \x03(\x0b\x32;.oak9.tython.gcp.logging.LoggingMetric.LabelExtractorsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x17\n\x0fvalue_extractor\x18\x07 \x01(\t\x12L\n\x0e\x62ucket_options\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.logging.LoggingMetricXBucketOptions\x12R\n\x11metric_descriptor\x18\t \x01(\x0b\x32\x37.oak9.tython.gcp.logging.LoggingMetricXMetricDescriptor\x12\x41\n\x08timeouts\x18\n \x01(\x0b\x32/.oak9.tython.gcp.logging.LoggingMetricXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x36\n\x14LabelExtractorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x01\n\x1fLoggingOrganizationBucketConfig\x12\x11\n\tbucket_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x17\n\x0flifecycle_state\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x14\n\x0corganization\x18\x07 \x01(\t\x12\x16\n\x0eretention_days\x18\x08 \x01(\x01\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x1cLoggingOrganizationExclusion\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06org_id\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\'LoggingOrganizationSinkXBigqueryOptions\x12\x1e\n\x16use_partitioned_tables\x18\x01 \x01(\x08\"i\n\"LoggingOrganizationSinkXExclusions\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xa8\x03\n\x17LoggingOrganizationSink\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x18\n\x10include_children\x18\x06 \x01(\x08\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0e\n\x06org_id\x18\x08 \x01(\t\x12\x17\n\x0fwriter_identity\x18\t \x01(\t\x12Z\n\x10\x62igquery_options\x18\n \x01(\x0b\x32@.oak9.tython.gcp.logging.LoggingOrganizationSinkXBigqueryOptions\x12O\n\nexclusions\x18\x0b \x03(\x0b\x32;.oak9.tython.gcp.logging.LoggingOrganizationSinkXExclusions\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xeb\x01\n\x1aLoggingProjectBucketConfig\x12\x11\n\tbucket_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x17\n\x0flifecycle_state\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x16\n\x0eretention_days\x18\x08 \x01(\x01\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb4\x01\n\x17LoggingProjectExclusion\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"D\n\"LoggingProjectSinkXBigqueryOptions\x12\x1e\n\x16use_partitioned_tables\x18\x01 \x01(\x08\"d\n\x1dLoggingProjectSinkXExclusions\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xa0\x03\n\x12LoggingProjectSink\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x1e\n\x16unique_writer_identity\x18\x08 \x01(\x08\x12\x17\n\x0fwriter_identity\x18\t \x01(\t\x12U\n\x10\x62igquery_options\x18\n \x01(\x0b\x32;.oak9.tython.gcp.logging.LoggingProjectSinkXBigqueryOptions\x12J\n\nexclusions\x18\x0b \x03(\x0b\x32\x36.oak9.tython.gcp.logging.LoggingProjectSinkXExclusions\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_logging_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGGINGMETRIC_LABELEXTRACTORSENTRY._options = None
  _LOGGINGMETRIC_LABELEXTRACTORSENTRY._serialized_options = b'8\001'
  _LOGGINGBILLINGACCOUNTBUCKETCONFIG._serialized_start=72
  _LOGGINGBILLINGACCOUNTBUCKETCONFIG._serialized_end=322
  _LOGGINGBILLINGACCOUNTEXCLUSION._serialized_start=325
  _LOGGINGBILLINGACCOUNTEXCLUSION._serialized_end=520
  _LOGGINGBILLINGACCOUNTSINKXBIGQUERYOPTIONS._serialized_start=522
  _LOGGINGBILLINGACCOUNTSINKXBIGQUERYOPTIONS._serialized_end=597
  _LOGGINGBILLINGACCOUNTSINKXEXCLUSIONS._serialized_start=599
  _LOGGINGBILLINGACCOUNTSINKXEXCLUSIONS._serialized_end=706
  _LOGGINGBILLINGACCOUNTSINK._serialized_start=709
  _LOGGINGBILLINGACCOUNTSINK._serialized_end=1122
  _LOGGINGFOLDERBUCKETCONFIG._serialized_start=1125
  _LOGGINGFOLDERBUCKETCONFIG._serialized_end=1358
  _LOGGINGFOLDEREXCLUSION._serialized_start=1361
  _LOGGINGFOLDEREXCLUSION._serialized_end=1539
  _LOGGINGFOLDERSINKXBIGQUERYOPTIONS._serialized_start=1541
  _LOGGINGFOLDERSINKXBIGQUERYOPTIONS._serialized_end=1608
  _LOGGINGFOLDERSINKXEXCLUSIONS._serialized_start=1610
  _LOGGINGFOLDERSINKXEXCLUSIONS._serialized_end=1709
  _LOGGINGFOLDERSINK._serialized_start=1712
  _LOGGINGFOLDERSINK._serialized_end=2118
  _LOGGINGLOGVIEWXTIMEOUTS._serialized_start=2120
  _LOGGINGLOGVIEWXTIMEOUTS._serialized_end=2193
  _LOGGINGLOGVIEW._serialized_start=2196
  _LOGGINGLOGVIEW._serialized_end=2492
  _LOGGINGMETRICXBUCKETOPTIONSXEXPLICITBUCKETS._serialized_start=2494
  _LOGGINGMETRICXBUCKETOPTIONSXEXPLICITBUCKETS._serialized_end=2555
  _LOGGINGMETRICXBUCKETOPTIONSXEXPONENTIALBUCKETS._serialized_start=2557
  _LOGGINGMETRICXBUCKETOPTIONSXEXPONENTIALBUCKETS._serialized_end=2671
  _LOGGINGMETRICXBUCKETOPTIONSXLINEARBUCKETS._serialized_start=2673
  _LOGGINGMETRICXBUCKETOPTIONSXLINEARBUCKETS._serialized_end=2775
  _LOGGINGMETRICXBUCKETOPTIONS._serialized_start=2778
  _LOGGINGMETRICXBUCKETOPTIONS._serialized_end=3097
  _LOGGINGMETRICXMETRICDESCRIPTORXLABELS._serialized_start=3099
  _LOGGINGMETRICXMETRICDESCRIPTORXLABELS._serialized_end=3192
  _LOGGINGMETRICXMETRICDESCRIPTOR._serialized_start=3195
  _LOGGINGMETRICXMETRICDESCRIPTOR._serialized_end=3384
  _LOGGINGMETRICXTIMEOUTS._serialized_start=3386
  _LOGGINGMETRICXTIMEOUTS._serialized_end=3458
  _LOGGINGMETRIC._serialized_start=3461
  _LOGGINGMETRIC._serialized_end=4010
  _LOGGINGMETRIC_LABELEXTRACTORSENTRY._serialized_start=3956
  _LOGGINGMETRIC_LABELEXTRACTORSENTRY._serialized_end=4010
  _LOGGINGORGANIZATIONBUCKETCONFIG._serialized_start=4013
  _LOGGINGORGANIZATIONBUCKETCONFIG._serialized_end=4258
  _LOGGINGORGANIZATIONEXCLUSION._serialized_start=4261
  _LOGGINGORGANIZATIONEXCLUSION._serialized_end=4445
  _LOGGINGORGANIZATIONSINKXBIGQUERYOPTIONS._serialized_start=4447
  _LOGGINGORGANIZATIONSINKXBIGQUERYOPTIONS._serialized_end=4520
  _LOGGINGORGANIZATIONSINKXEXCLUSIONS._serialized_start=4522
  _LOGGINGORGANIZATIONSINKXEXCLUSIONS._serialized_end=4627
  _LOGGINGORGANIZATIONSINK._serialized_start=4630
  _LOGGINGORGANIZATIONSINK._serialized_end=5054
  _LOGGINGPROJECTBUCKETCONFIG._serialized_start=5057
  _LOGGINGPROJECTBUCKETCONFIG._serialized_end=5292
  _LOGGINGPROJECTEXCLUSION._serialized_start=5295
  _LOGGINGPROJECTEXCLUSION._serialized_end=5475
  _LOGGINGPROJECTSINKXBIGQUERYOPTIONS._serialized_start=5477
  _LOGGINGPROJECTSINKXBIGQUERYOPTIONS._serialized_end=5545
  _LOGGINGPROJECTSINKXEXCLUSIONS._serialized_start=5547
  _LOGGINGPROJECTSINKXEXCLUSIONS._serialized_end=5647
  _LOGGINGPROJECTSINK._serialized_start=5650
  _LOGGINGPROJECTSINK._serialized_end=6066
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_deployment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_deployment.proto\x12\x1aoak9.tython.gcp.deployment\x1a\x13shared/shared.proto\"@\n\"DeploymentManagerDeploymentXLabels\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"<\n)DeploymentManagerDeploymentXTargetXConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"K\n*DeploymentManagerDeploymentXTargetXImports\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd4\x01\n\"DeploymentManagerDeploymentXTarget\x12U\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x45.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTargetXConfig\x12W\n\x07imports\x18\x02 \x03(\x0b\x32\x46.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTargetXImports\"V\n$DeploymentManagerDeploymentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x85\x04\n\x1b\x44\x65ploymentManagerDeployment\x12\x15\n\rcreate_policy\x18\x01 \x01(\t\x12\x15\n\rdelete_policy\x18\x02 \x01(\t\x12\x15\n\rdeployment_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08manifest\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07preview\x18\x08 \x01(\x08\x12\x0f\n\x07project\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12N\n\x06labels\x18\x0b \x03(\x0b\x32>.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXLabels\x12N\n\x06target\x18\x0c \x01(\x0b\x32>.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTarget\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.deployment.DeploymentManagerDeploymentXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_deployment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEPLOYMENTMANAGERDEPLOYMENTXLABELS._serialized_start=77
  _DEPLOYMENTMANAGERDEPLOYMENTXLABELS._serialized_end=141
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXCONFIG._serialized_start=143
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXCONFIG._serialized_end=203
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXIMPORTS._serialized_start=205
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGETXIMPORTS._serialized_end=280
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGET._serialized_start=283
  _DEPLOYMENTMANAGERDEPLOYMENTXTARGET._serialized_end=495
  _DEPLOYMENTMANAGERDEPLOYMENTXTIMEOUTS._serialized_start=497
  _DEPLOYMENTMANAGERDEPLOYMENTXTIMEOUTS._serialized_end=583
  _DEPLOYMENTMANAGERDEPLOYMENT._serialized_start=586
  _DEPLOYMENTMANAGERDEPLOYMENT._serialized_end=1103
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CanaryCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    S3_OBJECT_VERSION_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    HANDLER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    s3_key: builtins.str
    s3_object_version: builtins.str
    script: builtins.str
    handler: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        s3_key: builtins.str = ...,
        s3_object_version: builtins.str = ...,
        script: builtins.str = ...,
        handler: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["handler", b"handler", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key", "s3_object_version", b"s3_object_version", "script", b"script"]) -> None: ...

global___CanaryCode = CanaryCode

@typing_extensions.final
class CanarySchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    expression: builtins.str
    duration_in_seconds: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        expression: builtins.str = ...,
        duration_in_seconds: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "expression", b"expression", "resource_info", b"resource_info"]) -> None: ...

global___CanarySchedule = CanarySchedule

@typing_extensions.final
class CanaryVPCConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    vpc_id: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        vpc_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids", "vpc_id", b"vpc_id"]) -> None: ...

global___CanaryVPCConfig = CanaryVPCConfig

@typing_extensions.final
class CanaryRunConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_SECONDS_FIELD_NUMBER: builtins.int
    MEMORY_IN_MB_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    timeout_in_seconds: builtins.int
    memory_in_mb: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timeout_in_seconds: builtins.int = ...,
        memory_in_mb: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["memory_in_mb", b"memory_in_mb", "resource_info", b"resource_info", "timeout_in_seconds", b"timeout_in_seconds"]) -> None: ...

global___CanaryRunConfig = CanaryRunConfig

@typing_extensions.final
class Canary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    ARTIFACT_S3_LOCATION_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_ARN_FIELD_NUMBER: builtins.int
    RUNTIME_VERSION_FIELD_NUMBER: builtins.int
    SUCCESS_RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    FAILURE_RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    RUN_CONFIG_FIELD_NUMBER: builtins.int
    START_CANARY_AFTER_CREATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def code(self) -> global___CanaryCode: ...
    artifact_s3_location: builtins.str
    @property
    def schedule(self) -> global___CanarySchedule: ...
    execution_role_arn: builtins.str
    runtime_version: builtins.str
    success_retention_period: builtins.int
    failure_retention_period: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vpc_config(self) -> global___CanaryVPCConfig: ...
    @property
    def run_config(self) -> global___CanaryRunConfig: ...
    start_canary_after_creation: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        code: global___CanaryCode | None = ...,
        artifact_s3_location: builtins.str = ...,
        schedule: global___CanarySchedule | None = ...,
        execution_role_arn: builtins.str = ...,
        runtime_version: builtins.str = ...,
        success_retention_period: builtins.int = ...,
        failure_retention_period: builtins.int = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_config: global___CanaryVPCConfig | None = ...,
        run_config: global___CanaryRunConfig | None = ...,
        start_canary_after_creation: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["code", b"code", "resource_info", b"resource_info", "run_config", b"run_config", "schedule", b"schedule", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_s3_location", b"artifact_s3_location", "code", b"code", "execution_role_arn", b"execution_role_arn", "failure_retention_period", b"failure_retention_period", "name", b"name", "resource_info", b"resource_info", "run_config", b"run_config", "runtime_version", b"runtime_version", "schedule", b"schedule", "start_canary_after_creation", b"start_canary_after_creation", "success_retention_period", b"success_retention_period", "tags", b"tags", "vpc_config", b"vpc_config"]) -> None: ...

global___Canary = Canary

@typing_extensions.final
class Synthetics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CANARY_FIELD_NUMBER: builtins.int
    @property
    def canary(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Canary]: ...
    def __init__(
        self,
        *,
        canary: collections.abc.Iterable[global___Canary] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["canary", b"canary"]) -> None: ...

global___Synthetics = Synthetics



import os
import unittest

from core.bp_metadata_utils.policy import Policy
from core.bp_metadata_utils.policy_repo import PolicyRepo

this_dir = os.path.dirname(os.path.abspath(__file__))
test_data_path = os.path.join(this_dir, 'testdata', 'oak9')

class TestRepo(PolicyRepo):
    def __init__(self, url: str, local_path:str, skip_sync: bool, glob_pattern:str):
        super().__init__(url=url, local_path=local_path, skip_sync=skip_sync)
        self._glob_pattern = glob_pattern

    @property
    def glob_pattern(self) -> str:
        return self._glob_pattern

    def filter(self, policy: Policy) -> bool:
        pass

    def pre_filter(self, policy_file_path: str) -> bool:
        pass


class PolicyRepoTest(unittest.TestCase):
    def test_path_expansion(self):
        glob_pattern = os.path.join(test_data_path, '{azure,aws}', '*.py')
        want = [
            os.path.join(test_data_path, 'azure/well_formed_implements_field_multiple_values.py'),
            os.path.join(test_data_path, 'aws/well_formed_aws_config_implementation.py'),
        ]
        fixture = TestRepo(url='foo', local_path=test_data_path,  skip_sync=True, glob_pattern=glob_pattern)
        got = fixture.policy_file_paths
        self.assertEqual(got, want)


